==> haskell-wl-pprint-terminfo-3.7.1.4-78-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-terminfo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-terminfo
version: 3.7.1.4
id: wl-pprint-terminfo-3.7.1.4-azgPU8moC89JQPz0GbvZj
key: wl-pprint-terminfo-3.7.1.4-azgPU8moC89JQPz0GbvZj
license: BSD-3-Clause
copyright: Copyright (C) 2011 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/wl-pprint-terminfo/
synopsis: A color pretty printer with terminfo support
description:
    A color pretty printer with terminfo support
category: Control, Monads, Text
abi: 808549b8f59106b37803f73a73aa551e
exposed: True
exposed-modules:
    System.Console.Terminfo.PrettyPrint
hidden-modules: System.Console.Terminfo.PrettyPrint.Curses
import-dirs: /usr/lib/ghc-8.6.3/site-local/wl-pprint-terminfo-3.7.1.4
library-dirs: /usr/lib/ghc-8.6.3/site-local/wl-pprint-terminfo-3.7.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-wl-pprint-terminfo
hs-libraries: HSwl-pprint-terminfo-3.7.1.4-azgPU8moC89JQPz0GbvZj
extra-libraries:
    ncursesw
includes:
    cursed.h
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    terminfo-0.4.1.2 text-1.2.3.1 transformers-0.5.5.0
    wl-pprint-extras-3.5.0.5-GS1ZQo383WCCLAXTcXw7NT
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-terminfo/html/wl-pprint-terminfo.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-terminfo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-terminfo-3.7.1.4-79-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-terminfo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-terminfo
version: 3.7.1.4
id: wl-pprint-terminfo-3.7.1.4-CojjqNdPRH2cqeufilpMa
key: wl-pprint-terminfo-3.7.1.4-CojjqNdPRH2cqeufilpMa
license: BSD-3-Clause
copyright: Copyright (C) 2011 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/wl-pprint-terminfo/
synopsis: A color pretty printer with terminfo support
description:
    A color pretty printer with terminfo support
category: Control, Monads, Text
abi: 414d51191c183fd8de377e1ade20f98f
exposed: True
exposed-modules:
    System.Console.Terminfo.PrettyPrint
hidden-modules: System.Console.Terminfo.PrettyPrint.Curses
import-dirs: /usr/lib/ghc-8.6.3/site-local/wl-pprint-terminfo-3.7.1.4
library-dirs: /usr/lib/ghc-8.6.3/site-local/wl-pprint-terminfo-3.7.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-wl-pprint-terminfo
hs-libraries: HSwl-pprint-terminfo-3.7.1.4-CojjqNdPRH2cqeufilpMa
extra-libraries:
    ncursesw
includes:
    cursed.h
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    terminfo-0.4.1.2 text-1.2.3.1 transformers-0.5.5.0
    wl-pprint-extras-3.5.0.5-ETVnemnyeycEXrLHRPqvuS
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-terminfo/html/wl-pprint-terminfo.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-terminfo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
